<?php
/* Copyright (C) 2011  Stephan Kreutzer
 *
 * This file is part of Welt.
 *
 * Welt is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 * Welt is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Welt.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @file $/insert.php
 * @brief Automatic standalone script to insert an object into
 *     the map, if its placement causes an overlap over top and/or
 *     right corner.
 * @details Paramters are hard coded and will not be checked. So
 *     browse this file only if you have made adjustments in the
 *     code before.
 * @author Stephan Kreutzer
 * @since 2011-09-28
 */



require_once(dirname(__FILE__)."/libraries/database.inc.php");



define("VIEW_X", 800);
define("VIEW_Y", 600);



echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n".
     "<!DOCTYPE html\n".
     "    PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n".
     "    \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n".
     "\n".
     "\n".
     "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">\n".
     "\n".
     "\n".
     "  <head>\n".
     "\n".
     "\n".
     "      <title>Welt</title>\n".
     "\n".
     "      <meta http-equiv=\"expires\" content=\"1296000\" />\n".
     "      <meta http-equiv=\"content-type\" content=\"application/xhtml+xml; charset=UTF-8\" />\n".
     "\n".
     "\n".
     "  </head>\n".
     "\n".
     "\n".
     "  <body>\n".
     "\n".
     "\n".
     "      <p>\n";

insertMap(0, 0, 770, 30, 3, 100, "00:00:00", "24:00:00");

echo "      </p>\n".
     "\n".
     "\n".
     "  </body>\n".
     "\n".
     "\n".
     "</html>\n";



// Warning: for internal usage only! No parameter checks!
function insertMap($x, $y, $position_x, $position_y, $objectID, $order_z, $from, $to)
{
    $file = db_get_rows("SELECT `file`\n".
                        "FROM `objects`\n".
                        "WHERE `id`=".$objectID."\n");

    if (is_array($file) !== true)
    {
        echo "no object.<br />";
        return -1;
    }
    else
    {
        $file = $file[0]['file'];
    }

    $filePath = dirname(__FILE__)."/resources/".$file;
    $size = getimagesize($filePath);

    if ($position_x >= VIEW_X ||
        $position_x < 0 ||
        $position_y >= VIEW_Y ||
        $position_y < 0)
    {
        echo "out of range.<br />";
        return -1;
    }

    if ($size[0] > VIEW_X ||
        $size[0] <= 0 ||
        $size[1] > VIEW_Y ||
        $size[1] <= 0)
    {
        echo "bad size.<br />";
        return -2;
    }


    $id = db_insert("INSERT INTO `map` (`id`,\n".
                    "    `map_x`,\n".
                    "    `map_y`,\n".
                    "    `object_id`,\n".
                    "    `position_x`,\n".
                    "    `position_y`,\n".
                    "    `order_z`,\n".
                    "    `from`,\n".
                    "    `to`,\n".
                    "    `visible`)\n".
                    "VALUES (NULL,\n".
                    "    ".$x.",\n".
                    "    ".$y.",\n".
                    "    ".$objectID.",\n".
                    "    ".$position_x.",\n".
                    "    ".$position_y.",\n".
                    "    ".$order_z.",\n".
                    "    '".$from."',\n".
                    "    '".$to."',\n".
                    "    NULL)");

    echo "regular id: ".$id."<br />";

    // -1 for $size[0] if used in positioning context because
    // the image size is not zero-based but the coordinate system is.
    if ($position_x + ($size[0] - 1) >= VIEW_X)
    {
        // x over right.

        $id = db_insert("INSERT INTO `map` (`id`,\n".
                        "    `map_x`,\n".
                        "    `map_y`,\n".
                        "    `object_id`,\n".
                        "    `position_x`,\n".
                        "    `position_y`,\n".
                        "    `order_z`,\n".
                        "    `from`,\n".
                        "    `to`,\n".
                        "    `visible`)\n".
                        "VALUES (NULL,\n".
                        "    ".($x + 1).",\n".
                        "    ".$y.",\n".
                        "    ".$objectID.",\n".
                        "    ".($position_x - VIEW_X).",\n".
                        "    ".$position_y.",\n".
                        "    ".$order_z.",\n".
                        "    '".$from."',\n".
                        "    '".$to."',\n".
                        "    NULL)");
                        
        echo "x over right. id is: ".$id."<br />";
    }
    
    // -1 for $size[1] if used in positioning context because
    // the image size is not zero-based but the coordinate system is.
    if ($position_y - ($size[1] - 1) < 0)
    // Alternative: ($size[1] - 1) > $position_y (must have at least the space
    // for the entire object).
    {
        // y over top.
       
        $id = db_insert("INSERT INTO `map` (`id`,\n".
                        "    `map_x`,\n".
                        "    `map_y`,\n".
                        "    `object_id`,\n".
                        "    `position_x`,\n".
                        "    `position_y`,\n".
                        "    `order_z`,\n".
                        "    `from`,\n".
                        "    `to`,\n".
                        "    `visible`)\n".
                        "VALUES (NULL,\n".
                        "    ".$x.",\n".
                        "    ".($y - 1).",\n".
                        "    ".$objectID.",\n".
                        "    ".$position_x.",\n".
                        "    ".(VIEW_Y + $position_y).",\n".
                        "    ".$order_z.",\n".
                        "    '".$from."',\n".
                        "    '".$to."',\n".
                        "    NULL)");
                        
        echo "y over top. id is: ".$id."<br />";
    }

    // -1 for $size elements if used in positioning context because
    // the image size is not zero-based but the coordinate system is.
    if ($position_x + ($size[0] - 1) >= VIEW_X &&
        $position_y - ($size[1] - 1) < 0)
    {
        // x over right and y over top.

        $id = db_insert("INSERT INTO `map` (`id`,\n".
                        "    `map_x`,\n".
                        "    `map_y`,\n".
                        "    `object_id`,\n".
                        "    `position_x`,\n".
                        "    `position_y`,\n".
                        "    `order_z`,\n".
                        "    `from`,\n".
                        "    `to`,\n".
                        "    `visible`)\n".
                        "VALUES (NULL,\n".
                        "    ".($x + 1).",\n".
                        "    ".($y - 1).",\n".
                        "    ".$objectID.",\n".
                        "    ".($position_x - VIEW_X).",\n".
                        "    ".(VIEW_Y + $position_y).",\n".
                        "    ".$order_z.",\n".
                        "    '".$from."',\n".
                        "    '".$to."',\n".
                        "    NULL)");

        echo "x over right and y over top. id is: ".$id."<br />";
    }
}



?>